@@ -246,9 +246,13 @@ class Canvas(tkinter.Canvas):
                             defaults to 1
             @type width: int
         """
+        if len(points) < 2: 
+            #if you passed a list
+            points = tuple(points[0])
         assert hasattr(width, "__init__"), f"width must be an int not {type(width)}"# make sure width can be converted to int
         new = []
-        for x, y in points:
+        for z in points:
+            x, y = tuple(z)
             nx, ny = self.get_cor(x, y)
             new.append(nx)
             new.append(ny)
